@@ -562,6 +562,8 @@ sub evt_process_exit {
       #if (!$self->{donetime} || $self->{donetime}<time()) {
          $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
          $self->{statbm}->SetBitmap($self->{presshere});
+         $self->{statbm}->SetToolTip(
+            Wx::ToolTip->new( Wx::gettext('Press FA =>') ) );
          $self->{bb}->Enable(1);
          $self->{fp3}->Enable(1);
          $self->{cleanup}->Enable(1);
@@ -768,6 +770,8 @@ sub on_change {
          copy $key, cwd();
       }
       $self->{statbm}->SetBitmap($self->{presshere});
+      $self->{statbm}->SetToolTip(
+         Wx::ToolTip->new( Wx::gettext('Press FA =>') ) );
       $self->{dashboard}->SetLabel('Amazon EC2 Dashboard');
       $self->{dashboard}->SetBackgroundColour(Wx::Colour->new(32,161,35));
       $self->{bb}->SetBitmap($self->{bmp});
